@@ -430,6 +430,8 @@ get_message_data (CamelFolder *folder, const char *uid, CamelException *ex)
 	return ba;
 }
 
+#define MAILING_LIST_HEADERS "X-MAILING-LIST X-LOOP LIST-ID LIST-POST MAILING-LIST ORIGINATOR X-LIST RETURN-PATH X-BEENTHERE "
+
 static CamelMimeMessage *
 get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 {
@@ -439,6 +441,8 @@ get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 	CamelStreamFilter *filtered_stream;
 	CamelMimeFilter *crlffilter;
 	GByteArray *ba;
+	gchar **list_headers = NULL;
+	gboolean found_list = FALSE;
 
 	ba = get_message_data (folder, uid, ex);
 	if (!ba)
@@ -458,6 +462,24 @@ get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 	camel_object_unref (CAMEL_OBJECT (filtered_stream));
 	camel_mime_message_set_source (msg, exch->source);
 
+	if(camel_medium_get_header (CAMEL_MEDIUM (msg), "Sender")) {
+		list_headers = g_strsplit (MAILING_LIST_HEADERS, " ", 0);
+		if (list_headers) {
+			int i = 0;
+			while (list_headers[i]) {
+				if (camel_medium_get_header (CAMEL_MEDIUM (msg), list_headers[i])) {
+					found_list = TRUE;
+					break;
+				}
+				i++;
+			}
+			g_strfreev (list_headers);
+		}
+		
+		if (!found_list)
+			camel_medium_set_header (CAMEL_MEDIUM (msg), "X-Evolution-Mail-From-Delegate", "yes");
+	}
+
 	fix_broken_multipart_related (CAMEL_MIME_PART (msg));
 	return msg;
 }
@@ -715,18 +737,18 @@ static CamelSummaryMessageID *
 find_parent (CamelExchangeFolder *exch, const char *thread_index)
 {
 	CamelSummaryMessageID *msgid;
-	char *decoded, *parent;
-	int dlen;
+	guchar *decoded;
+	gchar *parent;
+	gsize dlen;
 
-	decoded = g_strdup (thread_index);
-	dlen = camel_base64_decode_simple (decoded, strlen (decoded));
+	decoded = g_base64_decode (thread_index, &dlen);
 	if (dlen < 5) {
 		/* Shouldn't happen */
 		g_free (decoded);
 		return NULL;
 	}
 
-	parent = camel_base64_encode_simple (decoded, dlen - 5);
+	parent = g_base64_encode (decoded, dlen - 5);
 	g_free (decoded);
 
 	msgid = g_hash_table_lookup (exch->thread_index_to_message_id,
